@@ -13,12 +13,12 @@
 #define GENSIO_BUILTINS_H
 
 #include <gensio/gensio_dllvisibility.h>
-#include <gensio/gensio.h>
+#include <gensio/gensio_types.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
-   
+
 /*
  * Allocators for the various gensio accepter types, compatible with
  * register_gensio_accepter().
@@ -116,6 +116,34 @@ int str_to_conacc_gensio_accepter(const char *str, const char * const args[],
 				  void *user_data,
 				  struct gensio_accepter **acc);
 
+GENSIO_DLL_PUBLIC
+int str_to_kiss_gensio_accepter(const char *str, const char * const args[],
+				struct gensio_os_funcs *o,
+				gensio_accepter_event cb,
+				void *user_data,
+				struct gensio_accepter **new_accepter);
+
+GENSIO_DLL_PUBLIC
+int str_to_ax25_gensio_accepter(const char *str, const char * const args[],
+				struct gensio_os_funcs *o,
+				gensio_accepter_event cb,
+				void *user_data,
+				struct gensio_accepter **acc);
+
+GENSIO_DLL_PUBLIC
+int str_to_xlt_gensio_accepter(const char *str, const char * const args[],
+			       struct gensio_os_funcs *o,
+			       gensio_accepter_event cb,
+			       void *user_data,
+			       struct gensio_accepter **new_accepter);
+
+GENSIO_DLL_PUBLIC
+int str_to_script_gensio_accepter(const char *str, const char * const args[],
+				  struct gensio_os_funcs *o,
+				  gensio_accepter_event cb,
+				  void *user_data,
+				  struct gensio_accepter **new_accepter);
+
 /*
  * Allocators for the various gensio types, compatible with
  * register_gensio().
@@ -210,7 +238,37 @@ int str_to_perf_gensio(const char *str, const char * const args[],
 		       struct gensio_os_funcs *o,
 		       gensio_event cb, void *user_data,
 		       struct gensio **new_gensio);
+GENSIO_DLL_PUBLIC
+int str_to_mdns_gensio(const char *str, const char * const args[],
+		       struct gensio_os_funcs *o,
+		       gensio_event cb, void *user_data,
+		       struct gensio **new_gensio);
+GENSIO_DLL_PUBLIC
+int str_to_kiss_gensio(const char *str, const char * const args[],
+		       struct gensio_os_funcs *o,
+		       gensio_event cb, void *user_data,
+		       struct gensio **new_gensio);
+GENSIO_DLL_PUBLIC
+int str_to_ax25_gensio(const char *str, const char * const args[],
+		       struct gensio_os_funcs *o,
+		       gensio_event cb, void *user_data,
+		       struct gensio **new_gensio);
+GENSIO_DLL_PUBLIC
+int str_to_xlt_gensio(const char *str, const char * const args[],
+		      struct gensio_os_funcs *o,
+		      gensio_event cb, void *user_data,
+		      struct gensio **new_gensio);
+GENSIO_DLL_PUBLIC
+int str_to_keepopen_gensio(const char *str, const char * const args[],
+			   struct gensio_os_funcs *o,
+			   gensio_event cb, void *user_data,
+			   struct gensio **new_gensio);
 
+GENSIO_DLL_PUBLIC
+int str_to_script_gensio(const char *str, const char * const args[],
+			 struct gensio_os_funcs *o,
+			 gensio_event cb, void *user_data,
+			 struct gensio **new_gensio);
 
 /*
  * Allocators for accepters for different I/O types.
@@ -331,13 +389,44 @@ int conacc_gensio_accepter_alloc(const char *gensio_str,
 				 gensio_accepter_event cb, void *user_data,
 				 struct gensio_accepter **accepter);
 
+GENSIO_DLL_PUBLIC
+int kiss_gensio_accepter_alloc(struct gensio_accepter *child,
+			       const char * const args[],
+			       struct gensio_os_funcs *o,
+			       gensio_accepter_event cb,
+			       void *user_data,
+			       struct gensio_accepter **new_accepter);
+
+GENSIO_DLL_PUBLIC
+int ax25_gensio_accepter_alloc(struct gensio_accepter *child,
+			       const char * const args[],
+			       struct gensio_os_funcs *o,
+			       gensio_accepter_event cb, void *user_data,
+			       struct gensio_accepter **accepter);
+
+GENSIO_DLL_PUBLIC
+int xlt_gensio_accepter_alloc(struct gensio_accepter *child,
+			      const char * const args[],
+			      struct gensio_os_funcs *o,
+			      gensio_accepter_event cb,
+			      void *user_data,
+			      struct gensio_accepter **new_accepter);
+
+GENSIO_DLL_PUBLIC
+int script_gensio_accepter_alloc(struct gensio_accepter *child,
+				 const char * const args[],
+				 struct gensio_os_funcs *o,
+				 gensio_accepter_event cb,
+				 void *user_data,
+				 struct gensio_accepter **new_accepter);
+
 /* Client allocators. */
 
 /*
  * Create a TCP gensio for the given ai.
  */
 GENSIO_DLL_PUBLIC
-int tcp_gensio_alloc(struct gensio_addr *ai, const char * const args[],
+int tcp_gensio_alloc(const struct gensio_addr *ai, const char * const args[],
 		     struct gensio_os_funcs *o,
 		     gensio_event cb, void *user_data,
 		     struct gensio **new_gensio);
@@ -346,7 +435,7 @@ int tcp_gensio_alloc(struct gensio_addr *ai, const char * const args[],
  * Create a TCP gensio for the given ai.
  */
 GENSIO_DLL_PUBLIC
-int unix_gensio_alloc(struct gensio_addr *ai, const char * const args[],
+int unix_gensio_alloc(const struct gensio_addr *ai, const char * const args[],
 		      struct gensio_os_funcs *o,
 		      gensio_event cb, void *user_data,
 		      struct gensio **new_gensio);
@@ -356,7 +445,7 @@ int unix_gensio_alloc(struct gensio_addr *ai, const char * const args[],
  * ai.
  */
 GENSIO_DLL_PUBLIC
-int udp_gensio_alloc(struct gensio_addr *ai, const char * const args[],
+int udp_gensio_alloc(const struct gensio_addr *ai, const char * const args[],
 		     struct gensio_os_funcs *o,
 		     gensio_event cb, void *user_data,
 		     struct gensio **new_gensio);
@@ -365,7 +454,7 @@ int udp_gensio_alloc(struct gensio_addr *ai, const char * const args[],
  * Create a SCTP gensio for the given ai.
  */
 GENSIO_DLL_PUBLIC
-int sctp_gensio_alloc(struct gensio_addr *ai, const char * const args[],
+int sctp_gensio_alloc(const struct gensio_addr *ai, const char * const args[],
 		      struct gensio_os_funcs *o,
 		      gensio_event cb, void *user_data,
 		      struct gensio **new_gensio);
@@ -397,13 +486,19 @@ int ipmisol_gensio_alloc(const char *devname, const char * const args[],
 			 struct gensio **new_gensio);
 
 GENSIO_DLL_PUBLIC
-int echo_gensio_alloc(const char * const argv[], const char * const args[],
+int echo_gensio_alloc(const char * const args[],
 		      struct gensio_os_funcs *o,
 		      gensio_event cb, void *user_data,
 		      struct gensio **new_gensio);
 
 GENSIO_DLL_PUBLIC
-int file_gensio_alloc(const char * const argv[], const char * const args[],
+int file_gensio_alloc(const char * const args[],
+		      struct gensio_os_funcs *o,
+		      gensio_event cb, void *user_data,
+		      struct gensio **new_gensio);
+
+GENSIO_DLL_PUBLIC
+int mdns_gensio_alloc(const char *str, const char * const args[],
 		      struct gensio_os_funcs *o,
 		      gensio_event cb, void *user_data,
 		      struct gensio **new_gensio);
@@ -459,6 +554,36 @@ int perf_gensio_alloc(struct gensio *child, const char * const args[],
 		      gensio_event cb, void *user_data,
 		      struct gensio **new_gensio);
 
+GENSIO_DLL_PUBLIC
+int kiss_gensio_alloc(struct gensio *child, const char * const args[],
+		      struct gensio_os_funcs *o,
+		      gensio_event cb, void *user_data,
+		      struct gensio **new_gensio);
+
+GENSIO_DLL_PUBLIC
+int ax25_gensio_alloc(struct gensio *child, const char * const args[],
+		      struct gensio_os_funcs *o,
+		      gensio_event cb, void *user_data,
+		      struct gensio **new_gensio);
+
+GENSIO_DLL_PUBLIC
+int xlt_gensio_alloc(struct gensio *child, const char * const args[],
+		     struct gensio_os_funcs *o,
+		     gensio_event cb, void *user_data,
+		     struct gensio **new_gensio);
+
+GENSIO_DLL_PUBLIC
+int keepopen_gensio_alloc(struct gensio *child, const char * const args[],
+			  struct gensio_os_funcs *o,
+			  gensio_event cb, void *user_data,
+			  struct gensio **new_gensio);
+
+GENSIO_DLL_PUBLIC
+int script_gensio_alloc(struct gensio *child, const char * const args[],
+			struct gensio_os_funcs *o,
+			gensio_event cb, void *user_data,
+			struct gensio **new_gensio);
+
 #ifdef __cplusplus
 }
 #endif
